/*
 * Bewerk dit bestand en kopieer het als userContent.css naar uw
 * profielmap/chrome/
 */

/*
 * Dit bestand kan gebruikt worden om een stijl toe te passen op alle websites
 * die u bekijkt
 * Regels zonder !important worden genegeerd indien de auteur eigen regels heeft 
 * ingesteld.  Regels met !important gaan voor auteursregels.
 */

/*
 * voorbeeld: het knipperen van "blink"-elementen uitschakelen
 *
 * blink { text-decoration: none ! important; }
 *
 */

/*
 * voorbeeld: voorzie alle tabellen van een 2px rand
 * 
 * table { border: 2px solid; }
 */

/*
 * voorbeeld: zet het "marquee"-element uit
 *
 * marquee { -moz-binding: none; }
 *
 */

/* 
 * Voor meer voorbeelden, zie http://www.mozilla.org/unix/customizing.html
 */
